@@ -17,19 +17,19 @@ from datetime import timedelta
 
 from urllib3.packages.six.moves.http_client import responses
 from urllib3.packages.six.moves.urllib.parse import urlsplit
-from urllib3.packages.six import binary_type
+from urllib3.packages.six import binary_type, ensure_str
 
 log = logging.getLogger(__name__)
 
 
 class Response(object):
-    def __init__(self, body='', status='200 OK', headers=None):
+    def __init__(self, body="", status="200 OK", headers=None):
         self.body = body
         self.status = status
         self.headers = headers or [("Content-type", "text/plain")]
 
     def __call__(self, request_handler):
-        status, reason = self.status.split(' ', 1)
+        status, reason = self.status.split(" ", 1)
         request_handler.set_status(int(status), reason)
         for header, value in self.headers:
             request_handler.add_header(header, value)
@@ -38,13 +38,13 @@ class Response(object):
         if isinstance(self.body, list):
             for item in self.body:
                 if not isinstance(item, bytes):
-                    item = item.encode('utf8')
+                    item = item.encode("utf8")
                 request_handler.write(item)
                 request_handler.flush()
         else:
             body = self.body
             if not isinstance(body, bytes):
-                body = body.encode('utf8')
+                body = body.encode("utf8")
 
             request_handler.write(body)
 
@@ -61,6 +61,7 @@ class TestingApp(RequestHandler):
     it exists. Status code 200 indicates success, 400 indicates failure. Each
     method has its own conditions for success/failure.
     """
+
     def get(self):
         """ Handle GET requests """
         self._call_method()
@@ -89,15 +90,15 @@ class TestingApp(RequestHandler):
             req.params[k] = next(iter(v))
 
         path = req.path[:]
-        if not path.startswith('/'):
+        if not path.startswith("/"):
             path = urlsplit(path).path
 
-        target = path[1:].replace('/', '_')
+        target = path[1:].replace("/", "_")
         method = getattr(self, target, self.index)
 
         resp = method(req)
 
-        if dict(resp.headers).get('Connection') == 'close':
+        if dict(resp.headers).get("Connection") == "close":
             # FIXME: Can we kill the connection somehow?
             pass
 
@@ -112,8 +113,7 @@ class TestingApp(RequestHandler):
         cert = request.get_ssl_certificate()
         subject = dict()
         if cert is not None:
-            subject = dict((k, v) for (k, v) in [y for z in cert['subject']
-                                                 for y in z])
+            subject = dict((k, v) for (k, v) in [y for z in cert["subject"] for y in z])
         return Response(json.dumps(subject))
 
     def source_address(self, request):
@@ -121,98 +121,110 @@ class TestingApp(RequestHandler):
         return Response(request.remote_ip)
 
     def set_up(self, request):
-        test_type = request.params.get('test_type')
-        test_id = request.params.get('test_id')
+        test_type = request.params.get("test_type")
+        test_id = request.params.get("test_id")
         if test_id:
-            print('\nNew test %s: %s' % (test_type, test_id))
+            print("\nNew test %s: %s" % (test_type, test_id))
         else:
-            print('\nNew test %s' % test_type)
+            print("\nNew test %s" % test_type)
         return Response("Dummy server is ready!")
 
     def specific_method(self, request):
         "Confirm that the request matches the desired method type"
-        method = request.params.get('method')
+        method = request.params.get("method")
         if method and not isinstance(method, str):
-            method = method.decode('utf8')
+            method = method.decode("utf8")
 
         if request.method != method:
-            return Response("Wrong method: %s != %s" %
-                            (method, request.method), status='400 Bad Request')
+            return Response(
+                "Wrong method: %s != %s" % (method, request.method),
+                status="400 Bad Request",
+            )
         return Response()
 
     def upload(self, request):
         "Confirm that the uploaded file conforms to specification"
         # FIXME: This is a huge broken mess
-        param = request.params.get('upload_param', b'myfile').decode('ascii')
-        filename = request.params.get('upload_filename', b'').decode('utf-8')
-        size = int(request.params.get('upload_size', '0'))
+        param = request.params.get("upload_param", b"myfile").decode("ascii")
+        filename = request.params.get("upload_filename", b"").decode("utf-8")
+        size = int(request.params.get("upload_size", "0"))
         files_ = request.files.get(param)
 
         if len(files_) != 1:
-            return Response("Expected 1 file for '%s', not %d" % (param, len(files_)),
-                            status='400 Bad Request')
+            return Response(
+                "Expected 1 file for '%s', not %d" % (param, len(files_)),
+                status="400 Bad Request",
+            )
         file_ = files_[0]
 
-        data = file_['body']
+        data = file_["body"]
         if int(size) != len(data):
-            return Response("Wrong size: %d != %d" %
-                            (size, len(data)), status='400 Bad Request')
+            return Response(
+                "Wrong size: %d != %d" % (size, len(data)), status="400 Bad Request"
+            )
 
-        got_filename = file_['filename']
-        if(isinstance(got_filename, binary_type)):
-            got_filename = got_filename.decode('utf-8')
+        got_filename = file_["filename"]
+        if isinstance(got_filename, binary_type):
+            got_filename = got_filename.decode("utf-8")
 
         # Tornado can leave the trailing \n in place on the filename.
         if filename != got_filename:
             return Response(
                 u"Wrong filename: %s != %s" % (filename, file_.filename),
-                status='400 Bad Request')
+                status="400 Bad Request",
+            )
 
         return Response()
 
     def redirect(self, request):
         "Perform a redirect to ``target``"
-        target = request.params.get('target', '/')
-        status = request.params.get('status', '303 See Other')
+        target = request.params.get("target", "/")
+        status = request.params.get("status", "303 See Other")
         if len(status) == 3:
-            status = '%s Redirect' % status.decode('latin-1')
+            status = "%s Redirect" % status.decode("latin-1")
 
-        headers = [('Location', target)]
+        headers = [("Location", target)]
         return Response(status=status, headers=headers)
 
     def not_found(self, request):
-        return Response('Not found', status='404 Not Found')
+        return Response("Not found", status="404 Not Found")
 
     def multi_redirect(self, request):
         "Performs a redirect chain based on ``redirect_codes``"
-        codes = request.params.get('redirect_codes', b'200').decode('utf-8')
-        head, tail = codes.split(',', 1) if "," in codes else (codes, None)
+        codes = request.params.get("redirect_codes", b"200").decode("utf-8")
+        head, tail = codes.split(",", 1) if "," in codes else (codes, None)
         status = "{0} {1}".format(head, responses[int(head)])
         if not tail:
             return Response("Done redirecting", status=status)
 
-        headers = [('Location', '/multi_redirect?redirect_codes=%s' % tail)]
+        headers = [("Location", "/multi_redirect?redirect_codes=%s" % tail)]
         return Response(status=status, headers=headers)
 
     def keepalive(self, request):
-        if request.params.get('close', b'0') == b'1':
-            headers = [('Connection', 'close')]
-            return Response('Closing', headers=headers)
+        if request.params.get("close", b"0") == b"1":
+            headers = [("Connection", "close")]
+            return Response("Closing", headers=headers)
 
-        headers = [('Connection', 'keep-alive')]
-        return Response('Keeping alive', headers=headers)
+        headers = [("Connection", "keep-alive")]
+        return Response("Keeping alive", headers=headers)
+
+    def echo_params(self, request):
+        params = sorted(
+            [(ensure_str(k), ensure_str(v)) for k, v in request.params.items()]
+        )
+        return Response(repr(params))
 
     def sleep(self, request):
         "Sleep for a specified amount of ``seconds``"
         # DO NOT USE THIS, IT'S DEPRECATED.
         # FIXME: Delete this once appengine tests are fixed to not use this handler.
-        seconds = float(request.params.get('seconds', '1'))
+        seconds = float(request.params.get("seconds", "1"))
         time.sleep(seconds)
         return Response()
 
     def echo(self, request):
         "Echo back the params"
-        if request.method == 'GET':
+        if request.method == "GET":
             return Response(request.query)
 
         return Response(request.body)
@@ -220,23 +232,25 @@ class TestingApp(RequestHandler):
     def encodingrequest(self, request):
         "Check for UA accepting gzip/deflate encoding"
         data = b"hello, world!"
-        encoding = request.headers.get('Accept-Encoding', '')
+        encoding = request.headers.get("Accept-Encoding", "")
         headers = None
-        if encoding == 'gzip':
-            headers = [('Content-Encoding', 'gzip')]
+        if encoding == "gzip":
+            headers = [("Content-Encoding", "gzip")]
             file_ = BytesIO()
-            with contextlib.closing(gzip.GzipFile('', mode='w', fileobj=file_)) as zipfile:
+            with contextlib.closing(
+                gzip.GzipFile("", mode="w", fileobj=file_)
+            ) as zipfile:
                 zipfile.write(data)
             data = file_.getvalue()
-        elif encoding == 'deflate':
-            headers = [('Content-Encoding', 'deflate')]
+        elif encoding == "deflate":
+            headers = [("Content-Encoding", "deflate")]
             data = zlib.compress(data)
-        elif encoding == 'garbage-gzip':
-            headers = [('Content-Encoding', 'gzip')]
-            data = 'garbage'
-        elif encoding == 'garbage-deflate':
-            headers = [('Content-Encoding', 'deflate')]
-            data = 'garbage'
+        elif encoding == "garbage-gzip":
+            headers = [("Content-Encoding", "gzip")]
+            data = "garbage"
+        elif encoding == "garbage-deflate":
+            headers = [("Content-Encoding", "deflate")]
+            data = "garbage"
         return Response(data, headers=headers)
 
     def headers(self, request):
@@ -247,10 +261,9 @@ class TestingApp(RequestHandler):
 
         It's not currently very flexible as the number of retries is hard-coded.
         """
-        test_name = request.headers.get('test-name', None)
+        test_name = request.headers.get("test-name", None)
         if not test_name:
-            return Response("test-name header not set",
-                            status="400 Bad Request")
+            return Response("test-name header not set", status="400 Bad Request")
 
         RETRY_TEST_NAMES[test_name] += 1
 
@@ -260,25 +273,23 @@ class TestingApp(RequestHandler):
             return Response("need to keep retrying!", status="418 I'm A Teapot")
 
     def chunked(self, request):
-        return Response(['123'] * 4)
+        return Response(["123"] * 4)
 
     def chunked_gzip(self, request):
         chunks = []
         compressor = zlib.compressobj(6, zlib.DEFLATED, 16 + zlib.MAX_WBITS)
 
-        for uncompressed in [b'123'] * 4:
+        for uncompressed in [b"123"] * 4:
             chunks.append(compressor.compress(uncompressed))
 
         chunks.append(compressor.flush())
 
-        return Response(chunks, headers=[('Content-Encoding', 'gzip')])
+        return Response(chunks, headers=[("Content-Encoding", "gzip")])
 
     def nbytes(self, request):
-        length = int(request.params.get('length'))
-        data = b'1' * length
-        return Response(
-            data,
-            headers=[('Content-Type', 'application/octet-stream')])
+        length = int(request.params.get("length"))
+        data = b"1" * length
+        return Response(data, headers=[("Content-Type", "application/octet-stream")])
 
     def status(self, request):
         status = request.params.get("status", "200 OK")
@@ -289,8 +300,8 @@ class TestingApp(RequestHandler):
         if datetime.now() - self.application.last_req < timedelta(seconds=1):
             status = request.params.get("status", b"429 Too Many Requests")
             return Response(
-                    status=status.decode('utf-8'),
-                    headers=[('Retry-After', '1')])
+                status=status.decode("utf-8"), headers=[("Retry-After", "1")]
+            )
 
         self.application.last_req = datetime.now()
 
@@ -298,15 +309,16 @@ class TestingApp(RequestHandler):
 
     def redirect_after(self, request):
         "Perform a redirect to ``target``"
-        date = request.params.get('date')
+        date = request.params.get("date")
         if date:
-            retry_after = str(httputil.format_timestamp(
-                    datetime.fromtimestamp(float(date))))
+            retry_after = str(
+                httputil.format_timestamp(datetime.fromtimestamp(float(date)))
+            )
         else:
-            retry_after = '1'
-        target = request.params.get('target', '/')
-        headers = [('Location', target), ('Retry-After', retry_after)]
-        return Response(status='303 See Other', headers=headers)
+            retry_after = "1"
+        target = request.params.get("target", "/")
+        headers = [("Location", target), ("Retry-After", retry_after)]
+        return Response(status="303 See Other", headers=headers)
 
     def shutdown(self, request):
         sys.exit()
