@@ -4,48 +4,54 @@ from urllib3.util import ssl_
 from urllib3.exceptions import SNIMissingWarning
 
 
-@pytest.mark.parametrize('addr', [
-    # IPv6
-    '::1',
-    '::',
-    'FE80::8939:7684:D84b:a5A4%251',
-
-    # IPv4
-    '127.0.0.1',
-    '8.8.8.8',
-    b'127.0.0.1',
-
-    # IPv6 w/ Zone IDs
-    'FE80::8939:7684:D84b:a5A4%251',
-    b'FE80::8939:7684:D84b:a5A4%251',
-    'FE80::8939:7684:D84b:a5A4%19',
-    b'FE80::8939:7684:D84b:a5A4%19'
-])
+@pytest.mark.parametrize(
+    "addr",
+    [
+        # IPv6
+        "::1",
+        "::",
+        "FE80::8939:7684:D84b:a5A4%251",
+        # IPv4
+        "127.0.0.1",
+        "8.8.8.8",
+        b"127.0.0.1",
+        # IPv6 w/ Zone IDs
+        "FE80::8939:7684:D84b:a5A4%251",
+        b"FE80::8939:7684:D84b:a5A4%251",
+        "FE80::8939:7684:D84b:a5A4%19",
+        b"FE80::8939:7684:D84b:a5A4%19",
+    ],
+)
 def test_is_ipaddress_true(addr):
     assert ssl_.is_ipaddress(addr)
 
 
-@pytest.mark.parametrize('addr', [
-    'www.python.org',
-    b'www.python.org',
-    'v2.sg.media-imdb.com',
-    b'v2.sg.media-imdb.com'
-])
+@pytest.mark.parametrize(
+    "addr",
+    [
+        "www.python.org",
+        b"www.python.org",
+        "v2.sg.media-imdb.com",
+        b"v2.sg.media-imdb.com",
+    ],
+)
 def test_is_ipaddress_false(addr):
     assert not ssl_.is_ipaddress(addr)
 
 
 @pytest.mark.parametrize(
-    ['has_sni', 'server_hostname', 'uses_sni'],
-    [(True, '127.0.0.1', False),
-     (False, 'www.python.org', False),
-     (False, '0.0.0.0', False),
-     (True, 'www.google.com', True),
-     (True, None, False),
-     (False, None, False)]
+    ["has_sni", "server_hostname", "uses_sni"],
+    [
+        (True, "127.0.0.1", False),
+        (False, "www.python.org", False),
+        (False, "0.0.0.0", False),
+        (True, "www.google.com", True),
+        (True, None, False),
+        (False, None, False),
+    ],
 )
 def test_context_sni_with_ip_address(monkeypatch, has_sni, server_hostname, uses_sni):
-    monkeypatch.setattr(ssl_, 'HAS_SNI', has_sni)
+    monkeypatch.setattr(ssl_, "HAS_SNI", has_sni)
 
     sock = mock.Mock()
     context = mock.create_autospec(ssl_.SSLContext)
@@ -59,21 +65,25 @@ def test_context_sni_with_ip_address(monkeypatch, has_sni, server_hostname, uses
 
 
 @pytest.mark.parametrize(
-    ['has_sni', 'server_hostname', 'should_warn'],
-    [(True, 'www.google.com', False),
-     (True, '127.0.0.1', False),
-     (False, '127.0.0.1', False),
-     (False, 'www.google.com', True),
-     (True, None, False),
-     (False, None, False)]
+    ["has_sni", "server_hostname", "should_warn"],
+    [
+        (True, "www.google.com", False),
+        (True, "127.0.0.1", False),
+        (False, "127.0.0.1", False),
+        (False, "www.google.com", True),
+        (True, None, False),
+        (False, None, False),
+    ],
 )
-def test_sni_missing_warning_with_ip_addresses(monkeypatch, has_sni, server_hostname, should_warn):
-    monkeypatch.setattr(ssl_, 'HAS_SNI', has_sni)
+def test_sni_missing_warning_with_ip_addresses(
+    monkeypatch, has_sni, server_hostname, should_warn
+):
+    monkeypatch.setattr(ssl_, "HAS_SNI", has_sni)
 
     sock = mock.Mock()
     context = mock.create_autospec(ssl_.SSLContext)
 
-    with mock.patch('warnings.warn') as warn:
+    with mock.patch("warnings.warn") as warn:
         ssl_.ssl_wrap_socket(sock, server_hostname=server_hostname, ssl_context=context)
 
     if should_warn:
@@ -86,8 +96,10 @@ def test_sni_missing_warning_with_ip_addresses(monkeypatch, has_sni, server_host
 
 @pytest.mark.parametrize(
     ["ciphers", "expected_ciphers"],
-    [(None, ssl_.DEFAULT_CIPHERS),
-     ("ECDH+AESGCM:ECDH+CHACHA20", "ECDH+AESGCM:ECDH+CHACHA20")]
+    [
+        (None, ssl_.DEFAULT_CIPHERS),
+        ("ECDH+AESGCM:ECDH+CHACHA20", "ECDH+AESGCM:ECDH+CHACHA20"),
+    ],
 )
 def test_create_urllib3_context_set_ciphers(monkeypatch, ciphers, expected_ciphers):
 
@@ -137,3 +149,18 @@ def test_wrap_socket_default_loads_default_certs(monkeypatch):
     ssl_.ssl_wrap_socket(sock)
 
     context.load_default_certs.assert_called_with()
+
+
+@pytest.mark.parametrize(
+    ["pha", "expected_pha"], [(None, None), (False, True), (True, True)]
+)
+def test_create_urllib3_context_pha(monkeypatch, pha, expected_pha):
+    context = mock.create_autospec(ssl_.SSLContext)
+    context.set_ciphers = mock.Mock()
+    context.options = 0
+    context.post_handshake_auth = pha
+    monkeypatch.setattr(ssl_, "SSLContext", lambda *_, **__: context)
+
+    assert ssl_.create_urllib3_context() is context
+
+    assert context.post_handshake_auth == expected_pha
